@@ -1,11 +1,11 @@
 /*
  *  gui.h
  *
- *  $Id: gui.h,v 1.8 2006/01/20 15:58:34 source Exp $
+ *  $Id$
  *
  *  The iODBC driver manager.
  *
- *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2014 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -79,6 +79,17 @@
 #ifndef	_GTKGUI_H
 #define _GTKGUI_H
 
+#define GLADE_HOOKUP_OBJECT(component,widget,name) \
+  gtk_widget_ref(widget); \
+  gtk_object_set_data_full (GTK_OBJECT (component), name, \
+      widget, (GtkDestroyNotify) gtk_widget_unref)
+
+#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
+  gtk_object_set_data (GTK_OBJECT (component), name, widget)
+
+#define _(X)  X
+
+
 typedef struct TLOGIN
 {
   GtkWidget *username, *password, *mainwnd;
