@@ -1,14 +1,14 @@
 /*
  *  sqltypes.h
  *
- *  $Id: sqltypes.h,v 1.23 2007/10/07 13:27:13 source Exp $
+ *  $Id$
  *
  *  ODBC typedefs
  *
  *  The iODBC driver manager.
  *
  *  Copyright (C) 1995 by Ke Jin <kejin@empress.com>
- *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2014 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -78,7 +78,6 @@
 #ifndef _SQLTYPES_H
 #define _SQLTYPES_H
 
-
 /*
  *  Set default specification to  ODBC 3.51
  */
@@ -86,6 +85,13 @@
 #define ODBCVER		0x0351
 #endif
 
+/*
+ *  Include Windows style defines and typedefs on Unix
+ */
+#ifndef _IODBCUNIX_H
+#include <iodbcunix.h>
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -337,7 +343,7 @@ SQL_INTERVAL_STRUCT;
  */
 #if (ODBCVER >= 0x0300)
 
-#if (_MSC_VER >= 900)
+#if defined(_MSC_VER) && (_MSC_VER >= 900)
 #  define ODBCINT64 		__int64
 #endif
 
