@@ -1,14 +1,14 @@
 /*
  *  connect.c
  *
- *  $Id: connect.c,v 1.53 2007/09/10 07:27:13 source Exp $
+ *  $Id$
  *
  *  Connect (load) driver
  *
  *  The iODBC driver manager.
  *
  *  Copyright (C) 1995 by Ke Jin <kejin@empress.com>
- *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2014 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -805,6 +805,7 @@ _iodbcdm_pool_get_conn (
 	  DPRINTF ((stderr, "DEBUG: connection %p expired (cp_expiry_time %d, current_time %d)\n",
             cp_pdbc, cp_pdbc->cp_expiry_time, current_time));
 	  _iodbcdm_pool_drop_conn (cp_pdbc, cp_pdbc_prev);
+          cp_pdbc = cp_pdbc_prev;
 	  continue;
         }
 
@@ -921,7 +922,7 @@ _iodbcdm_pool_get_conn (
 
 
 /*
- * Put the conneciton back to the pool
+ * Put the connection back to the pool
  *
  * Return 0 if the connection was put successfully
  * Return -1 otherwise
@@ -966,7 +967,7 @@ _iodbcdm_pool_put_conn (HDBC hdbc)
   if (cp_pdbc->cp_retry_wait == 0)
     {
       /* set new expiry time only if we are not returning the connection
-	 to the pool after unsuccessfull reconnect attempt */
+	 to the pool after unsuccessful reconnect attempt */
       cp_pdbc->cp_expiry_time = time(NULL) + cp_pdbc->cp_timeout;
     }
   cp_pdbc->cp_in_use = FALSE;
@@ -1006,6 +1007,7 @@ _iodbcdm_driverload (
   char *path = drv;
   char cp_probe[1024] = {""};
   int cp_timeout = 0;
+  void *pfaux;
 
   if (drv == NULL || ((char*)drv)[0] == '\0')
     {
@@ -1044,9 +1046,6 @@ _iodbcdm_driverload (
 	      path_tmp, sizeof (path_tmp), "odbcinst.ini") && path_tmp[0])
 	path = path_tmp;
 
-      if (tmp_drv)
-	free (tmp_drv);
-
       /*
        *  Get CPTimeout value
        */
@@ -1060,6 +1059,9 @@ _iodbcdm_driverload (
        */
       SQLGetPrivateProfileString (drv, "CPProbe", "",
    	    cp_probe, sizeof(cp_probe), "odbcinst.ini");
+
+      if (tmp_drv)
+	free (tmp_drv);
     }
   else if (dsn != NULL && *dsn != '\0')
     {
@@ -1184,7 +1186,8 @@ _iodbcdm_driverload (
           /*
            *  If the driver is Unicode
            */
-	  if ( _iodbcdm_getproc (pdbc, en_ConnectW))
+          pfaux = _iodbcdm_getproc (pdbc, en_ConnectW);
+          if ((pfaux) && (pfaux != (void *)SQLConnectW))
             penv->unicode_driver = 1;
 
 	  /* call driver's SQLAllocHandle() or SQLAllocEnv() */
@@ -1446,7 +1449,7 @@ _iodbcdm_driverunload (HDBC hdbc, int ver)
       penv->hdll = SQL_NULL_HDLL;
 
       for (tpenv = (ENV_t *) genv->henv;
-	  tpenv != NULL; tpenv = (ENV_t *) penv->next)
+	  tpenv != NULL; tpenv = (ENV_t *) tpenv->next)
 	{
 	  if (tpenv == penv)
 	    {
@@ -2598,7 +2601,7 @@ SQLDriverConnect_Internal (
 	    CFRelease (libname);
 	}
 #else
-      hdll = _iodbcdm_dllopen ("libiodbcadm.so");
+      hdll = _iodbcdm_dllopen ("libiodbcadm.so.2");
 #endif
 
       if (!hdll)
