@@ -1,14 +1,14 @@
 /*
  *  hstmt.h
  *
- *  $Id: hstmt.h,v 1.21 2009/08/30 10:48:33 source Exp $
+ *  $Id$
  *
  *  Query statement object management functions
  *
  *  The iODBC driver manager.
  *
  *  Copyright (C) 1995 by Ke Jin <kejin@empress.com>
- *  Copyright (C) 1996-2009 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2014 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -212,6 +212,22 @@ STMT_t;
         ODBC_UNLOCK()
 	
 
+#define ENTER_STMT_CANCEL(hstmt, trace) \
+	STMT (pstmt, hstmt); \
+	SQLRETURN retcode = SQL_SUCCESS; \
+	int stmt_cip = 0; \
+        ODBC_LOCK(); \
+	TRACE (trace); \
+    	if (!IS_VALID_HSTMT (pstmt)) \
+	  { \
+	    retcode = SQL_INVALID_HANDLE; \
+	    goto done; \
+	  } \
+	stmt_cip = pstmt->stmt_cip; \
+	CLEAR_ERRORS (pstmt); \
+        ODBC_UNLOCK()
+	
+
 #define LEAVE_STMT(hstmt, trace) \
 	ODBC_LOCK (); \
 	pstmt->stmt_cip = 0; \
@@ -221,6 +237,14 @@ STMT_t;
 	return (retcode)
 
 
+#define LEAVE_STMT_CANCEL(hstmt, trace) \
+	ODBC_LOCK (); \
+    done: \
+    	TRACE(trace); \
+	ODBC_UNLOCK (); \
+	return (retcode)
+
+
 enum
   {
     en_stmt_allocated = 0,
