@@ -1,13 +1,13 @@
 /*
  *  odbc3.c
  *
- *  $Id: odbc3.c,v 1.32 2007/09/04 06:25:24 source Exp $
+ *  $Id$
  *
  *  ODBC 3.x functions
  *
  *  The iODBC driver manager.
  *
- *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2014 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -1023,6 +1023,8 @@ SQLGetStmtAttr_Internal (
 	      PUSHSQLERR (stmt->herr, en_IM001);
 	      return SQL_ERROR;
             }
+	  if (ValuePtr)
+	    stmt->paramset_size = *((SQLUINTEGER *) ValuePtr);
 	  return retcode;
 	}
       else
@@ -1346,6 +1348,8 @@ SQLSetStmtAttr_Internal (
           PUSHSQLERR (stmt->herr, en_IM001);
           return SQL_ERROR;
         }
+      if (Attribute == SQL_ATTR_PARAM_BIND_TYPE)
+        stmt->bind_type = (SQLUINTEGER) (SQLULEN) ValuePtr;
       return retcode;
 
     case SQL_ATTR_ROWS_FETCHED_PTR:
@@ -1424,7 +1428,7 @@ SQLSetStmtAttr_Internal (
 	      PUSHSQLERR (stmt->herr, en_IM001);
 	      return SQL_ERROR;
             }
-
+	  stmt->paramset_size = (SQLUINTEGER) (SQLULEN) ValuePtr;
           return retcode;
 	}
       else
@@ -2385,6 +2389,7 @@ SQLSetDescField_Internal (
           break;
         }
     }
+
   CALL_UDRIVER(desc->hdbc, desc, retcode, hproc, penv->unicode_driver, 
     en_SetDescField, (desc->dhdesc, RecNumber, FieldIdentifier, ValuePtr,
     BufferLength));
