@@ -1,13 +1,13 @@
 /*
  *  trace.c
  *
- *  $Id: trace.c,v 1.24 2009/08/30 11:56:33 source Exp $
+ *  $Id$
  *
  *  Trace functions
  *
  *  The iODBC driver manager.
  *
- *  Copyright (C) 1996-2009 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2014 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -453,8 +453,6 @@ void
 trace_stop(void)
 {
   char mesgBuf[200];
-  time_t now;
-  struct tm *timeNow;
 
   if (trace_fp)
     {
@@ -512,11 +510,11 @@ trace_emit (char *fmt, ...)
 
 
 void
-trace_emit_string (SQLCHAR *str, int len, int is_utf8)
+trace_emit_string (SQLCHAR *str, ssize_t len, int is_utf8)
 {
   ssize_t length = len;
   int i, j;
-  long col;
+  int col;
   SQLCHAR *ptr;
   int bytes;
   int truncated = 0;
@@ -525,8 +523,8 @@ trace_emit_string (SQLCHAR *str, int len, int is_utf8)
     return;
 
   if (len == SQL_NTS)
-    length = strlen ((char *) str);
-  else if (len <= 0)
+    length = STRLEN ((char *) str);
+  if (len <= 0)
     return;
 
   /*
@@ -623,11 +621,11 @@ trace_emit_string (SQLCHAR *str, int len, int is_utf8)
 
 
 void
-trace_emit_binary (unsigned char *str, int len)
+trace_emit_binary (unsigned char *str, ssize_t  len)
 {
-  long length = len;
+  ssize_t length = len;
   int i;
-  long col;
+  int col;
   unsigned char *ptr;
   int truncated = 0;
   char buf[80];
@@ -959,7 +957,7 @@ _trace_ulen_p (SQLULEN *p, int output)
 void
 _trace_string (SQLCHAR * str, SQLSMALLINT len, SQLSMALLINT * lenptr, int output)
 {
-  long length;
+  ssize_t length;
 
   if (!str)
     {
@@ -996,7 +994,7 @@ void
 _trace_string_w (SQLWCHAR * str, SQLSMALLINT len, SQLSMALLINT * lenptr,
     int output)
 {
-  long length;
+  ssize_t length;
 
   if (!str)
     {
