@@ -1,11 +1,11 @@
 /*
  *  errorbox.c
  *
- *  $Id: errorbox.c,v 1.8 2007/02/02 11:58:14 source Exp $
+ *  $Id$
  *
  *  The iODBC driver manager.
  *
- *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2014 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -119,9 +119,11 @@ create_error (HWND hwnd, LPCSTR dsn, LPCSTR text, LPCSTR errmsg)
 
   gtk_object_set_data (GTK_OBJECT (error), "error", error);
   gtk_window_set_title (GTK_WINDOW (error), msg);
+  gtk_widget_set_size_request (error, 400, 150);
   gtk_window_set_position (GTK_WINDOW (error), GTK_WIN_POS_CENTER);
   gtk_window_set_modal (GTK_WINDOW (error), TRUE);
-  gtk_window_set_policy (GTK_WINDOW (error), FALSE, FALSE, FALSE);
+  gtk_window_set_default_size (GTK_WINDOW (error), 400, 150);
+  gtk_window_set_type_hint (GTK_WINDOW (error), GDK_WINDOW_TYPE_HINT_DIALOG);
 
 #if GTK_CHECK_VERSION(2,0,0)
   gtk_widget_show (error);
@@ -201,15 +203,13 @@ create_error (HWND hwnd, LPCSTR dsn, LPCSTR text, LPCSTR errmsg)
   gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox1), GTK_BUTTONBOX_END);
   gtk_button_box_set_spacing (GTK_BUTTON_BOX (hbuttonbox1), 10);
 
-  b_ok = gtk_button_new_with_label ("");
-  b_ok_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (b_ok)->child), "_Ok");
-  gtk_widget_add_accelerator (b_ok, "clicked", accel_group,
-      b_ok_key, GDK_MOD1_MASK, 0);
+  b_ok = gtk_button_new_from_stock ("gtk-ok");
   gtk_widget_ref (b_ok);
   gtk_object_set_data_full (GTK_OBJECT (error), "b_ok", b_ok,
       (GtkDestroyNotify) gtk_widget_unref);
   gtk_widget_show (b_ok);
   gtk_container_add (GTK_CONTAINER (hbuttonbox1), b_ok);
+  gtk_dialog_add_action_widget (GTK_DIALOG (error), b_ok, GTK_RESPONSE_OK);
   GTK_WIDGET_SET_FLAGS (b_ok, GTK_CAN_DEFAULT);
 
   /* Ok button events */
@@ -235,9 +235,9 @@ create_errorw (HWND hwnd, LPCWSTR dsn, LPCWSTR text, LPCWSTR errmsg)
   LPSTR _text = NULL;
   LPSTR _errmsg = NULL;
 
-  _dsn = dm_SQL_WtoU8(dsn, SQL_NTS);
-  _text = dm_SQL_WtoU8(text, SQL_NTS);
-  _errmsg = dm_SQL_WtoU8(errmsg, SQL_NTS);
+  _dsn = dm_SQL_WtoU8((SQLWCHAR*)dsn, SQL_NTS);
+  _text = dm_SQL_WtoU8((SQLWCHAR*)text, SQL_NTS);
+  _errmsg = dm_SQL_WtoU8((SQLWCHAR*)errmsg, SQL_NTS);
 
   create_error(hwnd, _dsn, _text, _errmsg);
 
